@@ -1,13 +1,12 @@
 # coding=utf-8
 from typing import Iterable
+
 from oeis.registry import registry
 
 
 @registry.register("A000040")
 def eratosthenes() -> Iterable[int]:
-    """
-    Sieve of Eratosthenes
-    """
+    """Sieve of Eratosthenes."""
     discards = {}
     p: int = 2
 
